#
# spec file for package python-pygit2
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-pygit2
Version:        0.24.0
Release:        2.9
Url:            http://github.com/dborowitz/pygit2
Summary:        Python bindings for libgit2
License:        GPL-2.0
Group:          Development/Languages/Python
Source:         https://pypi.io/packages/source/p/pygit2/pygit2-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  libgit2-devel >= 0.23
BuildRequires:  python-cffi
BuildRequires:  python-devel
BuildRequires:  python-six
#BuildRequires:  python-unittest2
BuildRequires:  libopenssl-devel
BuildRequires:  python-setuptools
%requires_eq    python-cffi

%description
Bindings for libgit2, a linkable C library for the Git version-control system.

%prep
%setup -n pygit2-%{version}
# Adjust include/lib paths to local system
#sed -i 's|/usr/local/include|%%{_includedir}|' setup.py
#sed -i 's|/usr/local/lib|%%{_libdir}|' setup.py

%build
CFLAGS="%{optflags} -fno-strict-aliasing" python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%check
#python setup.py test

%files
%defattr(-,root,root,-)
%doc COPYING README.rst
%{python_sitearch}/*

%changelog
* Fri Aug 12 2016 tbechtold@suse.com
- require the cffi version it was built against
- Use pypi.io as Source url
* Thu Apr  7 2016 zaitor@opensuse.org
- Update to version 0.24.0:
  + Support Python 3.5.
  + New dependency, python-six
  + New Repository.path_is_ignored(path).
  + Fix error in Repository(path) when path is a bytes string.
  + Fix memory issue in Repository.describe(...).
  + Allow testing with `tox.
- Add python-six BuildRequires following upstream changes.
* Tue Sep 29 2015 toddrme2178@gmail.com
- Update to version 0.23.1
  * Improve support for cffi 1.0+
    (https://github.com/libgit2/pygit2/pull/529)
    (https://github.com/libgit2/pygit2/pull/561)
  * Fix Remote.push
    (https://github.com/libgit2/pygit2/pull/557)
  * New TreeEntry.type
    (https://github.com/libgit2/pygit2/pull/560)
  * New pygit2.GIT_DIFF_SHOW_BINARY
    (https://github.com/libgit2/pygit2/pull/566)
* Thu Sep 17 2015 p.drouand@gmail.com
- Update to version 0.23.0
  * Update to libgit2 v0.23
    (https://github.com/libgit2/pygit2/pull/540)
  * Now Repository.merge_base(...) returns None if no merge base is found
    (https://github.com/libgit2/pygit2/pull/550)
  * Documentation updates
    (https://github.com/libgit2/pygit2/pull/547)
* Tue Feb  3 2015 dimstar@opensuse.org
- Update to version 0.22.0:
  + Update to libgit2 v0.22
    (https://github.com/libgit2/pygit2/pull/459)
  + Add support for libgit2 feature detection (new pygit2.features
    and pygit2.GIT_FEATURE_*)
    (https://github.com/libgit2/pygit2/pull/475)
  + New Repository.remotes (RemoteCollection)
    (https://github.com/libgit2/pygit2/pull/447)
  + API Changes:
  - Prototype of clone_repository changed, check documentation
  - Removed clone_into, use clone_repository with callbacks instead
  - Use Repository.remotes.rename(name, new_name) instead of
    Remote.rename(new_name)
  - Use Repository.remotes.delete(name) instead of Remote.delete()
  - Now Remote.push(...) takes a list of refspecs instead of just one
  - Change Patch.old_id, Patch.new_id, Note.annotated_id,
    RefLogEntry.oid_old and RefLogEntry.oid_new to be Oid objects
    instead of strings
    (https://github.com/libgit2/pygit2/pull/449)
  + Other:
  - Fix init_repository when passing optional parameters
    workdir_path, description, template_path, initial_head or
    origin_url.
  - Fix use-after-free when patch outlives diff.
  - Documentation improvements.
  - Make the GPL exception explicit in setup.py.
- Add python-setuptools BuildRequires: new build dependency.
* Tue Sep  2 2014 p.drouand@gmail.com
- Update to version 0.20.2
  + Fix regression with Python 2, ``IndexEntry.path`` returns str
    (bytes in Python 2 and unicode in Python 3)
  + Get back ``IndexEntry.oid`` for backwards compatibility
  + Config, iterate over the keys (instead of the key/value pairs)
    `#395 <https://github.com/libgit2/pygit2/pull/395>`_
  + ``Diff.find_similar`` supports new threshold arguments
    `#396 <https://github.com/libgit2/pygit2/pull/396>`_
  + Optimization, do not load the object when expanding an oid prefix
  `#397 <https://github.com/libgit2/pygit2/pull/397>`_
- Changes from version 0.20.1
  + Install fix
    `#382 <https://github.com/libgit2/pygit2/pull/382>`_
  + Documentation improved, including
    `#383 <https://github.com/libgit2/pygit2/pull/383>`_
    `#385 <https://github.com/libgit2/pygit2/pull/385>`_
    `#388 <https://github.com/libgit2/pygit2/pull/388>`_
  + Documentation, use the read-the-docs theme
    `#387 <https://github.com/libgit2/pygit2/pull/387>`_
  + Coding style improvements
    `#392 <https://github.com/libgit2/pygit2/pull/392>`_
  + New ``Repository.state_cleanup()``
    `#386 <https://github.com/libgit2/pygit2/pull/386>`_
  + New ``Index.conflicts``
    `#345 <https://github.com/libgit2/pygit2/issues/345>`_
    `#389 <https://github.com/libgit2/pygit2/pull/389>`_
  + New checkout option to define the target directory
    `#390 <https://github.com/libgit2/pygit2/pull/390>`_
- Fix build
- Remove python_sitelib definition; pygit2 is arch dependant
- Add python-cffi and python-unittest2 requirements; new
  dependencies
- Disable tests; network is now needed for launching them
* Mon Dec  9 2013 p.drouand@gmail.com
- Update to version 0.20.0
  + Upstream provides no changelog, but you can check
    https://github.com/libgit2/pygit2/compare/v0.19.0...v0.20.0
- Fix build on openSUSE >= 12.3 and SLE11SP3
- Remove obsolete conditionnal macros
* Sun Aug 18 2013 toddrme2178@gmail.com
- Update to 0.19.0
  + Upstream provides no changelog, but you can check
    https://github.com/libgit2/pygit2/compare/v0.17.3...v0.19.0
- Keep 0.17.3 for compatibility with openSUSE 12.2
* Thu Dec 27 2012 cfarrell@suse.com
- license update: GPL-2.0
  See COPYING (and the majority of the source code files). Not sure why
  Apache-2.0 was chosen as license here - there is absolutely no indication
  of Apache style licensing in the package
* Tue Dec 18 2012 saschpe@suse.de
- Update to version 0.17.3:
  + Upstream provides no changelog, but you can check
    https://github.com/libgit2/pygit2/compare/v0.17.2...v0.17.3
- Changes from previous versions:
  + https://github.com/libgit2/pygit2/compare/v0.16.1...v0.17.2
- Enable testsuite again
- Package file COPYING
* Tue Apr 24 2012 saschpe@suse.de
- Update to version 0.16.1:
  + Upstream provides no changelog
* Wed Jan 26 2011 saschpe@gmx.de
- Removed SUSE-specific --record-rpm for file lists
* Tue Jan 18 2011 saschpe@gmx.de
- Install documentation (README.md and COPYING)
- Fix install section for other distros
* Tue Jan 18 2011 saschpe@gmx.de
- Initial commit (0.1)
- Added patch include recent libgit2 changes
